Directions class abstract

Implemented types
Implementers

Constructors

Directions()

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

createCarparksLayer(MapWindow mapWindow) → CarparksLayer
Creates the carparks layer.
createDrivingRouter(DrivingRouterType type) → DrivingRouter
Creates a manager that builds driving routes.
isValid() → bool
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited