DrivingActionMetadata class final

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

asExitMetadata() → DrivingExitMetadata?
asLeaveRoundaboutMetadata() → DrivingLeaveRoundaboutMetadata?
asTurnMetadata() → DrivingTurnMetadata?
asUturnMetadata() → DrivingUturnMetadata?
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited
when({required void onUturnMetadata(DrivingUturnMetadata value), required void onLeaveRoundaboutMetadata(DrivingLeaveRoundaboutMetadata value), required void onTurnMetadata(DrivingTurnMetadata value), required void onExitMetadata(DrivingExitMetadata value)}) → void
Applies the passed function to the variant value.

Operators

operator ==(Object other) → bool
The equality operator.
inherited