DrivingAvoidanceFlagsNative class final

Inheritance
Implemented types
Available extensions

Properties

address → Pointer<T>

Available on T, provided by the StructAddress extension

The memory address of the underlying data.
no setter
avoidBoatFerry ↔ bool
getter/setter pair
avoidFordCrossing ↔ bool
getter/setter pair
avoidHighway ↔ bool
getter/setter pair
avoidPoorCondition ↔ bool
getter/setter pair
avoidRailwayCrossing ↔ bool
getter/setter pair
avoidTolls ↔ bool
getter/setter pair
avoidTunnel ↔ bool
getter/setter pair
avoidUnpaved ↔ bool
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited