DrivingExitMetadata class final

Available extensions

Constructors

DrivingExitMetadata({int? sequentialNumber, int? numerationProximityMask})
const

Properties

hashCode → int
The hash code for this object.
no setteroverride
numerationProximityMask → int?
Determines whether it is necessary to annotate the exit number in the imm stage.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
sequentialNumber → int?
The number in the sequence of consecutive exits.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
override

Operators

operator ==(covariant DrivingExitMetadata other) → bool
The equality operator.
override