DrivingRoute class abstract

Driving route. A route consists of multiple sections. Each section has a corresponding annotation that describes the action at the beginning of the section.

Implemented types

Constructors

DrivingRoute()

Properties

annotationLanguage → AnnotationLanguage?
Language of string annotations (for example street names) in this route object.
no setter
areConditionsOutdated → bool
Indicates whether driving conditions (jamSegments and events) have become outdated when we are not able to fetch updates for some predefined time.
no setter
checkpoints → List<DrivingCheckpoint>
Checkpoints
no setter
directionSigns → List<DrivingDirectionSign>
Direction signs.
no setter
events → List<DrivingEvent>
Events on the given route.
no setter
ferries → List<DrivingFerry>
no setter
fordCrossings → List<DrivingFordCrossing>
no setter
geometry → Polyline
Route geometry.
no setter
hashCode → int
The hash code for this object.
no setterinherited
highways → List<DrivingHighway>
no setter
jamSegments → List<JamSegment>
Traffic conditions on the given route.
no setter
laneSigns → List<DrivingLaneSign>
Lane signs.
no setter
legIndex ↔ int
A leg is a section of the route between two consecutive waypoints.
getter/setter pair
manoeuvreVehicleRestrictions → List<DrivingManoeuvreVehicleRestriction>
no setter
metadata → DrivingRouteMetadata
The route metadata.
no setter
pedestrianCrossings → List<DrivingPedestrianCrossing>
Pedestrian crossings
no setter
position ↔ PolylinePosition
The reached position on the given route. The 'RouteMetadata::weight' field contains data for the part of the route beyond this position.
getter/setter pair
railwayCrossings → List<DrivingRailwayCrossing>
Railway crossings
no setter
requestPoints → List<RequestPoint>?
Request points that were specified in the router request that this route originated from.
no setter
restrictedEntries → List<DrivingRestrictedEntry>
Route restricted entries.
no setter
restrictedTurns → List<DrivingRestrictedTurn>
Route points with time-dependent restrictions.
no setter
roadVehicleRestrictions → List<DrivingRoadVehicleRestriction>
Route vehicle restrictions.
no setter
routeId → String
The ID of the route.
no setter
routePosition → RoutePosition
The reached position on the given route. The 'RouteMetadata::weight' field contains data for the part of the route beyond this position.
no setter
ruggedRoads → List<DrivingRuggedRoad>
Route roads.
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
sections → List<DrivingSection>
Manoeuvre-to-Manoeuvre route sections.
no setter
speedBumps → List<DrivingSpeedBump>
Speed bumps
no setter
speedLimits → List<double?>
Speed limits for segments in the geometry.
no setter
tollRoads → List<DrivingTollRoad>
no setter
trafficLights → List<DrivingTrafficLight>
Route traffic lights.
no setter
tunnels → List<DrivingTunnel>
no setter
vehicleOptions → DrivingVehicleOptions
Vehicle options.
no setter
wayPoints → List<PolylinePosition>
Polyline positions of waypoints including start and finish point.
no setter
zoneCrossings → List<DrivingZoneCrossing>
no setter

Methods

addConditionsListener(DrivingConditionsListener conditionsListener) → void
Adds a listener for route condition changes.
metadataAt(PolylinePosition position) → DrivingRouteMetadata
Metadata location.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
removeConditionsListener(DrivingConditionsListener conditionsListener) → void
Removes the listener for route condition changes.
requestConditionsUpdate() → void
sectionIndex(int segmentIndex) → int
Section index.
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited