DrivingRouteMetadata class abstract final

Information about driving route metadata.

Inheritance
Implemented types

Constructors

DrivingRouteMetadata(DrivingWeight weight, DrivingFlags flags, List<DrivingRoutePoint> routePoints, String? uri, DrivingNonAvoidedFeatures? nonAvoidedFeatures)
factory

Properties

flags → DrivingFlags
Overall route characteristics.
no setter
hashCode → int
The hash code for this object.
no setteroverride
nonAvoidedFeatures → DrivingNonAvoidedFeatures?
Route features that cannot be avoided
no setter
routePoints → List<DrivingRoutePoint>
Route points. In addition to point coordinates each route point may have a selected arrival point
no setter
runtimeFactory → StructFactory
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
uri → String?
Route URI
no setter
weight → DrivingWeight
Route "weight".
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
override

Operators

operator ==(covariant DrivingRouteMetadata other) → bool
The equality operator.
override

Static Properties

factory → StructFactory<DrivingRouteMetadata>
final