DrivingWeight class final

Quantitative characteristics of any segment of the route.

Available extensions

Constructors

DrivingWeight(LocalizedValue time, LocalizedValue timeWithTraffic, LocalizedValue distance)
const

Properties

distance → LocalizedValue
Distance to travel.
final
hashCode → int
The hash code for this object.
no setteroverride
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
time → LocalizedValue
Time to travel, not considering traffic.
final
timeWithTraffic → LocalizedValue
Time to travel, considering traffic.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
override

Operators

operator ==(covariant DrivingWeight other) → bool
The equality operator.
override