Balloon class final

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

asAlternativeBalloon() → AlternativeBalloon?
asLaneSignBalloon() → LaneSignBalloon?
asManoeuvreBalloon() → ManoeuvreBalloon?
asManoeuvreWithLaneSignBalloon() → ManoeuvreWithLaneSignBalloon?
asRouteSummaryBalloon() → RouteSummaryBalloon?
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited
when({required void onManoeuvreBalloon(ManoeuvreBalloon value), required void onManoeuvreWithLaneSignBalloon(ManoeuvreWithLaneSignBalloon value), required void onLaneSignBalloon(LaneSignBalloon value), required void onRouteSummaryBalloon(RouteSummaryBalloon value), required void onAlternativeBalloon(AlternativeBalloon value)}) → void
Applies the passed function to the variant value.

Operators

operator ==(Object other) → bool
The equality operator.
inherited