NavigationCustomRouteOptions class final

Constructors

const

Properties

allowMoreUturns → bool?
Enabling this option will reduce the total route mileage but will include more u-turns along the route
final
hashCode → int
The hash code for this object.
no setteroverride
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
override

Operators

operator ==(covariant NavigationCustomRouteOptions other) → bool
The equality operator.
override