NavigationStyleProvider class abstract

Provides default style and icons when for navigation_layer objects when their look is refreshed (for example on creation or on night mode switch).

Implementers

Constructors

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited