RouteView class abstract

Implemented types

Constructors

RouteView()

Properties

balloonViews → List<BalloonView>
Balloons displayed on map about the route.
no setter
hashCode → int
The hash code for this object.
no setterinherited
route → DrivingRoute
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

isValid() → bool
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited