SpeedControlHighlightStyle class final

Available extensions

Constructors

SpeedControlHighlightStyle(Color strokeColor, Color fillColor, Duration animationDuration, Point<double> pulsationCenter, {required double strokeWidth, required double maximumRadius})
const

Properties

animationDuration → Duration
Sets the time it takes for the circle to reach its maximum size.
final
fillColor → Color
final
hashCode → int
The hash code for this object.
no setteroverride
maximumRadius → double
Sets the maximum circle radius in units.
final
pulsationCenter → Point<double>
Pulsation center on road event pin image. (0, 0) is top left and (1.0, 1.0) is bottom right.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
strokeColor → Color
final
strokeWidth → double
Sets the stroke width in units. The size of a unit is equal to the size of a pixel at the current zoom level when the camera position's tilt is equal to 0 and the scale factor is equal to 1.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
override

Operators

operator ==(covariant SpeedControlHighlightStyle other) → bool
The equality operator.
override