SearchEncyclopediaObjectMetadata class abstract final

Snippet with encyclopedia data.

Inheritance
Implemented types

Constructors

SearchEncyclopediaObjectMetadata(String? title, String? description, Attribution? attribution)
factory

Properties

attribution → Attribution?
Attribution information.
no setter
description → String?
Encyclopedia article body.
no setter
hashCode → int
The hash code for this object.
no setteroverride
runtimeFactory → StructFactory
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
title → String?
Encyclopedia article title.
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
override

Operators

operator ==(covariant SearchEncyclopediaObjectMetadata other) → bool
The equality operator.
override

Static Properties

factory → StructFactory<SearchEncyclopediaObjectMetadata>
final