SearchFeatureEnumValue class abstract final

Value for enumerated features.

Implemented types

Constructors

SearchFeatureEnumValue(String id, String name, String? imageUrlTemplate, List<String> tags)
factory

Properties

hashCode → int
The hash code for this object.
no setteroverride
id → String
Machine readable value identifier.
no setter
imageUrlTemplate → String?
urlTemplate for the image. Available sizes are listed here: http://api.mappable.ru/fotki/doc/format-ref/f-img.xml
no setter
name → String
Human readable localized representation.
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
tags → List<String>
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
override

Operators

operator ==(covariant SearchFeatureEnumValue other) → bool
The equality operator.
override