SearchPlaceInfo class abstract final

Related place information.

Implemented types

Constructors

SearchPlaceInfo(String name, String? uri, String? photoUrlTemplate, String? logId, Point? point, String? category, String? shortName, double? rating, SearchWorkingHours? workingHours, String? address, List<String> tag)
factory

Properties

address → String?
Formatted address for an organization.
no setter
category → String?
Place category as a string.
no setter
hashCode → int
The hash code for this object.
no setteroverride
logId → String?
Server-generated log identifier.
no setter
name → String
Place name.
no setter
photoUrlTemplate → String?
Url template for place photo.
no setter
point → Point?
Place position.
no setter
rating → double?
Place rating as number in 0 to 10 range.
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
shortName → String?
Short name for a place.
no setter
tag → List<String>
Tags
no setter
uri → String?
Place URI.
no setter
workingHours → SearchWorkingHours?
Open hours for a place.
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
override

Operators

operator ==(covariant SearchPlaceInfo other) → bool
The equality operator.
override