SearchResponse class abstract final

Top level structure for search response.

Implemented types

Constructors

SearchResponse(SearchMetadata metadata, GeoObjectCollection collection, bool isOffline)
factory

Properties

collection → GeoObjectCollection
List of objects (organizations, toponyms) in search response.
no setter
hashCode → int
The hash code for this object.
no setteroverride
isOffline → bool
Flag describing if this response was built offline.
no setter
metadata → SearchMetadata
Extended response information.
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
override

Operators

operator ==(covariant SearchResponse other) → bool
The equality operator.
override