SearchResultItem class abstract

Wrapper of the GeoObject in response, which makes it easy to get the certain fields from GeoObject

Implemented types

Constructors

SearchResultItem()

Properties

categoryClass → String?
CategoryClass (optional, first if there are several)
no setter
geoObject → GeoObject
Wrapped GeoObject itself
no setter
hashCode → int
The hash code for this object.
no setterinherited
id → String
Id (constructed inside)
no setter
name → String
Name (from GeoObject)
no setter
point → Point
Point from the GeoObject
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

details() → List<SearchSubtitleItem>
Details for the subtitle
hasDetails() → bool
Does the GeoObject contain details for subtitle
isClosed() → bool
Is the organization closed now
isCollection() → bool
Is it a collection GeoObject
isOffline() → bool
Is the GeoObject found in offline search
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited