SuggestItem class abstract final

A single suggested item.

Implemented types

Constructors

SuggestItem(SuggestItemType type, SpannableString title, SpannableString? subtitle, List<String> tags, String searchText, String? displayText, String? uri, String? link, LocalizedValue? distance, bool isPersonal, SuggestItemAction action, String? logId, bool isOffline, bool isWordItem, List<KeyValuePair> properties, Point? center, SuggestItemBusinessContext? businessContext)
factory

Properties

action → SuggestItemAction
Action to perform on click/tap/enter.
no setter
businessContext → SuggestItemBusinessContext?
Detailed subtype of the Business type
no setter
center → Point?
Position of object.
no setter
displayText → String?
Text to display if searchText is too technical to display.
no setter
distance → LocalizedValue?
Optional distance localized value.
no setter
hashCode → int
The hash code for this object.
no setteroverride
isOffline → bool
Item is from offline search.
no setter
isPersonal → bool
If the suggested item respects personalization.
no setter
isWordItem → bool
Item is a word suggest item.
no setter
Element link, if applicable.
no setter
logId → String?
Id for request logging.
no setter
properties → List<KeyValuePair>
Additional item properties.
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
searchText → String
Text to search for.
no setter
subtitle → SpannableString?
If type is TOPONYM returns reversed toponym hierarchy, if type is BUSINESS returns business address.
no setter
tags → List<String>
Additional free-form data for suggest item. If type is TOPONYM, returns toponym kind (house/street/locality/...). If type is BUSINESS, returns category class (drugstores/restaurants/...).
no setter
title → SpannableString
Short object name.
no setter
type → SuggestItemType
Suggested object type.
no setter
uri → String?
Element uri, if applicable.
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
override

Operators

operator ==(covariant SuggestItem other) → bool
The equality operator.
override