MasstransitLineStyle class final

Describes the style of line.

Available extensions

Constructors

MasstransitLineStyle({int? color})
const

Properties

color → int?
Line color in #RRGGBB format.
final
hashCode → int
The hash code for this object.
no setteroverride
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
override

Operators

operator ==(covariant MasstransitLineStyle other) → bool
The equality operator.
override