MasstransitStopFeatureMask class final

Describes various features a stop can have.

Available extensions

Constructors

MasstransitStopFeatureMask({required bool cooled, required bool heated})
const

Properties

cooled → bool
The stop is cooled at hot weather conditions.
final
hashCode → int
The hash code for this object.
no setteroverride
heated → bool
The stop is heated at cold weather conditions.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
override

Operators

operator ==(covariant MasstransitStopFeatureMask other) → bool
The equality operator.
override