MasstransitThread class abstract final

Describes a public transport thread. A thread is one of the MasstransitLine variants. For example, one line can have two threads: direct and return.

Inheritance
Implemented types

Constructors

MasstransitThread(String id, List<MasstransitEssentialStop> essentialStops, String? description, List<MasstransitThreadCategory> category, String? comfortClass)
factory

Properties

category → List<MasstransitThreadCategory>
List of categories describing important traits of the thread. For example, "primary", "secondary", "to_depot"
no setter
comfortClass → String?
Comfort class of transport, e.g. "Standart plus", "Lastochka" for trains.
no setter
description → String?
'Description' is a specific thread name which must be used in addition to the corresponding MasstransitLine name.
no setter
essentialStops → List<MasstransitEssentialStop>
List of important stops on the thread, such as the first and last stops.
no setter
hashCode → int
The hash code for this object.
no setteroverride
id → String
Thread ID.
no setter
runtimeFactory → StructFactory
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
override

Operators

operator ==(covariant MasstransitThread other) → bool
The equality operator.
override

Static Properties

factory → StructFactory<MasstransitThread>
final