MasstransitTransfer class abstract final

Represents a transfer to another mass transit line or to another stop. For example, transfer from one underground line to another.

Implemented types

Constructors

MasstransitTransfer(List<MasstransitConstructionSegment> constructions, MasstransitTransferStop transferStop)
factory

Properties

constructions → List<MasstransitConstructionSegment>
Compressed information about pedestrian constructions along the transfer path. MasstransitConstructionSegment.subpolyline fields of all segments cover the entire geometry of corresponding section".
no setter
hashCode → int
The hash code for this object.
no setteroverride
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
transferStop → MasstransitTransferStop
The stop you need to transfer to
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
override

Operators

operator ==(covariant MasstransitTransfer other) → bool
The equality operator.
override